@@ -5,6 +5,8 @@ import os
 import re
 import sys
 
+from abirules_tools import find_abinit_toplevel_directory, find_src_dirs
+
 # Init regular expressions
 re_m4file  = re.compile("\.m4$")
 re_hdrfile  = re.compile("\.h$")
@@ -31,7 +33,8 @@ cpp_explicit = [
 cpp_ignored = [
   "HAVE_CONFIG_H",
   "HAVE_IBM6",
-  "LIBPAW_HAVE_FOX"
+  "HAVE_LIBPAW_ABINIT",
+  "LIBPAW_HAVE_FOX",
 ]
 
 cpp_keywords = ("#","endif","ifdef","ifndef","elif","if","else","defined","[<>=]=?[ ]*[0-9]*","\\|\\|","&&","\\(","\\)","!")
@@ -47,15 +50,16 @@ def check_name(cpp_option,cpp_blocks):
   return ret
 
 
-def main(opts):
-  chk_verbose = opts.verbose
-
-  # Init script
-  my_name = os.path.basename(__file__) + ":main"
+def main():
+  top = find_abinit_toplevel_directory()
+  verbose = 0
 
   # Extract CPP options from the libPAW header files
+  #libpaw_dir = os.path.join(top, "src", "39_libpaw")
+  libpaw_dir = os.path.join(top, "shared", "libpaw")
+  assert os.path.isdir(libpaw_dir)
   cpp_libpaw = list()
-  for root,dirs,files in os.walk("src/42_libpaw"):
+  for root,dirs,files in os.walk(libpaw_dir):
     for src in files:
       if ( re_hdrfile.search(src) ):
         with open(os.path.join(root,src), "rt") as fh:
@@ -66,8 +70,10 @@ def main(opts):
                   cpp_libpaw.append(tmp_def)
 
   # Extract CPP options from the libTetra header files
+  libtetra_dir = os.path.join(top, "shared", "common", "src", "17_libtetra_ext")
+  assert os.path.isdir(libtetra_dir)
   cpp_libtetra = list()
-  for root,dirs,files in os.walk("src/17_libtetra_ext"):
+  for root,dirs,files in os.walk(libtetra_dir):
     for src in files:
       if ( re_hdrfile.search(src) ):
         with open(os.path.join(root,src), "rt") as fh:
@@ -79,17 +85,18 @@ def main(opts):
 
   # Extract CPP options from the build system
   cpp_buildsys = list()
-  for root,dirs,files in os.walk("config/m4"):
+  m4_path = os.path.join(top, "config", "m4")
+  assert os.path.isdir(m4_path)
+  for root,dirs,files in os.walk(m4_path):
     for src in files:
-      if not re_m4file.search(src): continue
-      with open(os.path.join(root, src), "rt") as fh:
-          for line in fh:
-            if re_acdef.search(line):
-              tmp_def = re.sub(".*AC_DEFINE\\([\\[]?([^\\],]*).*","\\1",line).strip()
-              if not tmp_def in cpp_buildsys:
-                cpp_buildsys.append(tmp_def)
-
-  with open("configure.ac", "rt") as fh:
+      if ( src.endswith(".m4") ):
+        with open(os.path.join(root, src), "rt") as fh:
+            for line in fh:
+              if re_acdef.search(line):
+                tmp_def = re.sub(".*AC_DEFINE\\([\\[]?([^\\],]*).*","\\1",line).strip()
+                if not tmp_def in cpp_buildsys:
+                  cpp_buildsys.append(tmp_def)
+  with open(os.path.join(top, "configure.ac"), "rt") as fh:
       for line in fh:
         if ( re_acdef.search(line) ):
           tmp_def = re.sub(".*AC_DEFINE\\([\\[]?([^\\],]*).*","\\1",line).strip()
@@ -109,8 +116,10 @@ def main(opts):
         cpp_blocks[i].append(tmp[i])
 
   # Extract CPP options from the includes
+  incs_dir = os.path.join(top, "src", "incs")
+  assert os.path.isdir(incs_dir)
   cpp_includes = list()
-  for root,dirs,files in os.walk("src/incs"):
+  for root,dirs,files in os.walk(incs_dir):
     for src in files:
       if not re_hdrfile.search(src): continue
       with open(os.path.join(root,src), "rt") as fh:
@@ -128,48 +137,50 @@ def main(opts):
 
   # Explore the source files
   cpp_source = dict()
-  for root,dirs,files in os.walk("src"):
+  #src_dir = os.path.join(top, "src")
+  #assert os.path.isdir(src_dir)
+  for src_dir in find_src_dirs():
+      for root,dirs,files in os.walk(src_dir):
+        files.sort()
+        for src in files:
+          if re_f90file.search(src):
+            with open(os.path.join(root, src), "rt") as fh:
+              f90_buffer = fh.readlines()
+            cpp_load = False
+            for i in range(len(f90_buffer)):
+              line = f90_buffer[i]
 
-    files.sort()
-    for src in files:
-      if re_f90file.search(src):
-        with open(os.path.join(root, src), "rt") as fh:
-          f90_buffer = fh.readlines()
-        cpp_load = False
-        for i in range(len(f90_buffer)):
-          line = f90_buffer[i]
+              # Record CPP lines
+              if ( re_cppline.search(line) ):
+                if ( cpp_load ):
+                  sys.stderr.write("%s: %s:%d: Error: unterminated CPP directive\n" % \
+                    (my_name,src,i+1))
+                  sys.exit(1)
+                cpp_load = True
+                cpp_buffer = ""
 
-          # Record CPP lines
-          if ( re_cppline.search(line) ):
-            if ( cpp_load ):
-              sys.stderr.write("%s: %s:%d: Error: unterminated CPP directive\n" % \
-                (my_name,src,i+1))
-              sys.exit(1)
-            cpp_load = True
-            cpp_buffer = ""
+              # Process CPP lines
+              if ( cpp_load ):
+                cpp_buffer += line
+                if ( not re_cppcont.search(line) ):
+                  if ( not re_cppskip.search(line) ):
 
-          # Process CPP lines
-          if ( cpp_load ):
-            cpp_buffer += line
-            if ( not re_cppcont.search(line) ):
-              if ( not re_cppskip.search(line) ):
+                    # Extract CPP options
+                    for kwd in cpp_keywords:
+                      cpp_buffer = re.sub(kwd,"",cpp_buffer)
+                    cpp_buffer = re.sub("[\n\t ]+"," ",cpp_buffer)
+                    cpp_buffer = cpp_buffer.strip()
+                    cpp_buffer = cpp_buffer.split()
 
-                # Extract CPP options
-                for kwd in cpp_keywords:
-                  cpp_buffer = re.sub(kwd,"",cpp_buffer)
-                cpp_buffer = re.sub("[\n\t ]+"," ",cpp_buffer)
-                cpp_buffer = cpp_buffer.strip()
-                cpp_buffer = cpp_buffer.split()
+                    # Register CPP options
+                    for opt in cpp_buffer:
+                      if ( not opt in cpp_ignored ):
+                        if ( not opt in cpp_source ):
+                          cpp_source[opt] = list()
+                        cpp_source[opt].append("%s/%s:%d" % (root,src,i+1))
 
-                # Register CPP options
-                for opt in cpp_buffer:
-                  if ( not opt in cpp_ignored ):
-                    if ( not opt in cpp_source ):
-                      cpp_source[opt] = list()
-                    cpp_source[opt].append("%s/%s:%d" % (root,src,i+1))
-
-              # Reset 
-              cpp_load = False
+                  # Reset
+                  cpp_load = False
 
   # Process CPP option information
   cpp_keys = list(cpp_source.keys())
@@ -187,12 +198,12 @@ def main(opts):
   cpp_misnamed.sort()
 
   # Display forbidden CPP options
-  if ( (chk_verbose and (len(cpp_devel) > 0)) or (len(cpp_undefined) > 0) ):
+  if ( (verbose and (len(cpp_devel) > 0)) or (len(cpp_undefined) > 0) ):
     sys.stderr.write("%s: reporting preprocessing option discrepancies\n\n" % \
       (os.path.basename(sys.argv[0])))
     sys.stderr.write("X: N=Wrong Naming / U=Undefined\n\n")
 
-  if ( chk_verbose and (len(cpp_devel) > 0) ):
+  if ( verbose and (len(cpp_devel) > 0) ):
     sys.stderr.write("%s  %-24s  %-44s\n" % ("X","Developer option","Location"))
     sys.stderr.write("%s  %-24s  %-44s\n" % ("-","-" *24,"-" * 48))
     for opt in cpp_devel:
@@ -223,16 +234,4 @@ def main(opts):
   return retval
 
 if __name__ == "__main__":
-  # Parse command-line arguments
-  from optparse import OptionParser
-
-  my_help = "Usage: %prog [-v|--verbose]"""
-  parser = OptionParser(usage=my_help, version="%prog for Abinit 6")
-  parser.add_option("-v", "--verbose", action="store_true",
-    dest="verbose", default=False,
-    help="Report developer options")
-
-  (opts, args) = parser.parse_args()
-
-  exit_status = main(opts)
-  sys.exit(exit_status)
+  sys.exit(main())
