@@ -13,6 +13,7 @@ subsuites = [
 "depes",
 "eph",
 "ffield",
+"lw",
 "nlo",
 "optic",   
 "rf1",
@@ -44,6 +45,13 @@ inp_files = [
 "tffield_5.in",
 "tffield_6.in",
 #"-tffield_7.in",  # Disabled
+"tlw_1.in",
+"tlw_2.in",
+"tlw_3.in",
+"tlw_4.in",
+"tlw_5.in",
+"tlw_6.in",
+"tlw_7.in",
 "tnlo_1.in",
 "tnlo_2.in",
 "tnlo_3.in",
@@ -59,6 +67,7 @@ inp_files = [
 "toptic_2.in",
 "toptic_3.in",
 "toptic_4.in",
+"toptic_5.in",
 "trf1_1.in",
 "trf1_2.in",
 "trf1_3.in",
