@@ -11,6 +11,7 @@ keywords = [
 #: List of input files
 inp_files = [
 "t01.in",
+"t01_triqs2_0.in",
 "t02.in",
 "t03.in",
 "t04.in",
@@ -32,6 +33,13 @@ inp_files = [
 "t20.in",
 "t21.in",
 "t22.in",
+"t23.in",
+"t24.in",
+"t25.in",
+"t26.in",
+"t27.in",
+"t28.in",
+"t29.in",
 "t30.in",
 "t31.in",
 "t32.in",
@@ -40,6 +48,8 @@ inp_files = [
 "t35.in",
 "t36.in",
 "t37.in",
+"t38.in",
+"t39.in",
 "t41.in",
 "t42.in",
 "t43.in",
@@ -51,9 +61,14 @@ inp_files = [
 "t49.in",
 "t50.in",
 "t51.in",
+"t52.in",
+"t53.in",
+"t54.in",
 "t55.in",
 "t56.in",
 "t57.in",
+"t58.in",
+"t59.in",
 "t61.in",
 "t62.in",
 "t63.in",
@@ -89,4 +104,13 @@ inp_files = [
 "t91.in",
 "t92.in",
 "t93.in",
+"t94.in",
+#Non-collinear magnetization + nspden=4
+"t95.in",
+"t96.in",
+"t97.in",
+#Additional-multibinit tests 
+"t98.in", 
+"t99.in",
+"t100.in",
 ]
